embeddings
===========

.. automodule:: prem.resources.embeddings.resource
   :members: Embeddings
   :undoc-members:
   :show-inheritance:

models
------

.. autoclass:: prem.resources.embeddings.models.EmbeddingsResponse
   :members:
   :undoc-members:

.. autoclass:: prem.resources.embeddings.models.Usage
   :members:
   :undoc-members:
